summaryrefslogtreecommitdiffstats
path: root/src/borrowerdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/borrowerdialog.h')
-rw-r--r--src/borrowerdialog.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/borrowerdialog.h b/src/borrowerdialog.h
index 0b490b5..9bb6d02 100644
--- a/src/borrowerdialog.h
+++ b/src/borrowerdialog.h
@@ -37,7 +37,7 @@ Q_OBJECT
TQ_OBJECT
public:
- static Data::BorrowerPtr getBorrower(TQWidget* tqparent);
+ static Data::BorrowerPtr getBorrower(TQWidget* parent);
private slots:
void selectItem(const TQString& name);
@@ -48,10 +48,10 @@ private:
/**
* The constructor sets up the dialog.
*
* @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/
- BorrowerDialog(TQWidget* tqparent, const char* name=0);
+ BorrowerDialog(TQWidget* parent, const char* name=0);
Data::BorrowerPtr borrower();
TQString m_uid;
@@ -61,8 +61,8 @@ private:
class Item : public KListViewItem {
public:
- Item(KListView* tqparent, const KABC::Addressee& addressee);
- Item(KListView* tqparent, const Data::Borrower& borrower);
+ Item(KListView* parent, const KABC::Addressee& addressee);
+ Item(KListView* parent, const Data::Borrower& borrower);
const TQString& uid() const { return m_uid; }
private:
@@ -48,10 +48,10 @@ private:
* The constructor sets up the dialog.
*
- * @param tqparent A pointer to the tqparent widget
+ * @param parent A pointer to the parent widget
* @param name The widget name
*/